@@ -21,6 +21,12 @@ class Group(OperationGroup):
         path="/api/v1/apis/{api_name}/resource_versions/",
     )
 
+    # 生成
+    generate_sdk = bind_property(
+        Operation, name="generate_sdk", method="POST",
+        path="/api/v1/apis/{api_name}/sdk/",
+    )
+
     # 获取网关公钥
     get_apigw_public_key = bind_property(
         Operation, name="get_apigw_public_key", method="GET",
@@ -56,6 +62,12 @@ class Group(OperationGroup):
         path="/api/v1/apis/{api_name}/resource_versions/release/",
     )
 
+    # 回收应用访问网关 API 的权限
+    revoke_permissions = bind_property(
+        Operation, name="revoke_permissions", method="DELETE",
+        path="/api/v1/apis/{api_name}/permissions/revoke/",
+    )
+
     # 同步策略
     sync_access_strategy = bind_property(
         Operation, name="sync_access_strategy", method="POST",
@@ -80,6 +92,12 @@ class Group(OperationGroup):
         path="/api/v1/apis/{api_name}/stages/sync/",
     )
 
+    # 更新微网关实例状态
+    update_micro_gateway_status = bind_property(
+        Operation, name="update_micro_gateway_status", method="PUT",
+        path="/api/v1/edge-controller/micro-gateway/{instance_id}/status/",
+    )
+
 
 class Client(APIGatewayClient):
     """bk-apigateway
