@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-from . import conf
 from .base import RequestAPI
 
 
 class CollectionsAPI(object):
     def __init__(self, client):
+        from . import conf
+
         self.client = client
         self.host = "" or conf.HOST.format(api_name="bk-apigateway")
 
@@ -33,3 +34,9 @@ class CollectionsAPI(object):
         self.import_resource_docs_by_swagger = RequestAPI(client=self.client, method="POST", host=self.host, path="/api/v1/apis/{api_name}/resource-docs/import/by-swagger/")
 
         self.add_related_apps = RequestAPI(client=self.client, method="POST", host=self.host, path="/api/v1/apis/{api_name}/related-apps/")
+
+        self.revoke_permissions = RequestAPI(client=self.client, method="DELETE", host=self.host, path="/api/v1/apis/{api_name}/permissions/revoke/")
+
+        self.update_micro_gateway_status = RequestAPI(client=self.client, method="PUT", host=self.host, path="/api/v1/edge-controller/micro-gateway/{instance_id}/status/")
+
+        self.generate_sdk = RequestAPI(client=self.client, method="POST", host=self.host, path="/api/v1/apis/{api_name}/sdk/")
